@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.16"
+__version__ = "1.0.17"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -28,9 +28,9 @@ from qubell.api.private import exceptions
 
 class QubellPlatform(object):
 
-    def __init__(self, auth=None, context=None):
+    def __init__(self, context, auth=None):
         self.organizations = []
-        self.auth = context | auth
+        self.auth = auth | context
         self.user = self.auth.user
         self.password = self.auth.password
         self.tenant = self.auth.tenant
